require 'rails_helper'

describe 'DeletableJobConcern' do
  it "delete other job and perform the right one" do
    # Call jobs to init execution
    job1 = build(:dummy_deleteable_job).perform_later(1) 
    job2 = build(:dummy_deleteable_job).perform_later(1) 
    job3 = build(:dummy_deleteable_job).perform_later(1) 
    expect(Resque.enqueued_jobs.count).to eq(3)

    perform_enqueued_jobs do
      job = enqueued_jobs.sample
      job[:job].perform_now(*job[:args])
    end

    # DummyCreateable instance created by dummy job
    expect(DummyCreateable.count).to eq(1)
    expect(Resque.enqueued_jobs.count).to eq(0)
  end

  it "with mutliple args" do
    job1 = build(:dummy_deleteable_job).perform_later(1, [1, 2], '3', { key: 'value' }) 
    job2 = build(:dummy_deleteable_job).perform_later(1, [1, 2], '3', { key: 'value' }) 
    job3 = build(:dummy_deleteable_job).perform_later(1, [1, 2], '3', { key: 'value' }) 
    expect(Resque.enqueued_jobs.count).to eq(3)

    perform_enqueued_jobs do
      job = enqueued_jobs.sample
      job[:job].perform_now(*job[:args])
    end

    # DummyCreateable instance created by dummy job
    expect(DummyCreateable.count).to eq(1)
    expect(Resque.enqueued_jobs.count).to eq(0)
  end

  it "with hash arg" do
    job1 = build(:dummy_deleteable_job).perform_later({ key: 'value', key2: ['value2'], key3: 3 }) 
    job2 = build(:dummy_deleteable_job).perform_later({ key: 'value', key2: ['value2'], key3: 3 }) 
    job3 = build(:dummy_deleteable_job).perform_later({ key: 'value', key2: ['value2'], key3: 3 }) 
    expect(Resque.enqueued_jobs.count).to eq(3)

    perform_enqueued_jobs do
      job = enqueued_jobs.sample
      job[:job].perform_now(*job[:args])
    end

    # DummyCreateable instance created by dummy job
    expect(DummyCreateable.count).to eq(1)
    expect(Resque.enqueued_jobs.count).to eq(0)
  end
end